      * [SAP Discovery Inbox](https://help.sap.com/docs/leanix/ea/sap-landscape-discovery-inbox?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [AI Agent Discovery](https://help.sap.com/docs/leanix/ea/ai-agent-discovery?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Uploading AI Agents Through the API](https://help.sap.com/docs/leanix/ea/discovering-ai-agents-using-api?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Discovering AI Agents from Microsoft Entra ID](https://help.sap.com/docs/leanix/ea/discovering-ai-agents-from-microsoft-entra-id?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Discovering AI Agents from Google Agent Engine](https://help.sap.com/docs/leanix/ea/discovering-ai-agents-from-google-agent-engine?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Discovering SAP AI Agents](https://help.sap.com/docs/leanix/ea/discovering-sap-ai-agents?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Discovering MCP Servers from Microsoft Azure API Center](https://help.sap.com/docs/leanix/ea/discovering-mcp-servers-from-microsoft-azure-api-center?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Discovering AI Agents from Amazon Bedrock](https://help.sap.com/docs/leanix/ea/discovering-ai-agents-from-amazon-bedrock?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [AI Agent Discovery Inbox](https://help.sap.com/docs/leanix/ea/ai-agent-discovery-inbox?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [SAP Cloud ALM Integration For Managing Projects](https://help.sap.com/docs/leanix/ea/sap-cloud-alm-integration-for-managing-projects?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Configuring SAP Cloud ALM Integration For Managing Projects](https://help.sap.com/docs/leanix/ea/configuring-sap-cloud-alm-integration-for-managing-projects?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Synchronizing Projects Between SAP Cloud ALM and SAP LeanIX](https://help.sap.com/docs/leanix/ea/synchronizing-projects-between-sap-cloud-alm-and-sap-leanix?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [SAP Signavio Integration](https://help.sap.com/docs/leanix/ea/sap-signavio-integration?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Configuring the Integration](https://help.sap.com/docs/leanix/ea/configuring-integration?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Mapping SAP Signavio Processes to Fact Sheets](https://help.sap.com/docs/leanix/ea/mapping-sap-signavio-processes-to-fact-sheets?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Mapping Fact Sheets and Dictionary Items](https://help.sap.com/docs/leanix/ea/mapping-fact-sheets-and-dictionary-items?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Synchronizing Process Variants](https://help.sap.com/docs/leanix/ea/synchronizing-process-variants?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Best Practices and Tutorials](https://help.sap.com/docs/leanix/ea/best-practices-and-tutorials?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Advanced Configuration](https://help.sap.com/docs/leanix/ea/sap-signavio-advanced-configuration?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [ServiceNow Integration](https://help.sap.com/docs/leanix/ea/servicenow-integration?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Setup in ServiceNow](https://help.sap.com/docs/leanix/ea/setup-in-servicenow?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Setup in SAP LeanIX](https://help.sap.com/docs/leanix/ea/setup-in-sap-leanix?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Aggregation and Linkage of Software Records](https://help.sap.com/docs/leanix/ea/aggregation-and-linkage-of-software-records?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Fact Sheet Mapping Between ServiceNow and SAP LeanIX](https://help.sap.com/docs/leanix/ea/fact-sheet-mapping-between-servicenow-and-sap-leanix?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Matching Rules](https://help.sap.com/docs/leanix/ea/matching-rules?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Relation Mapping Between ServiceNow and SAP LeanIX](https://help.sap.com/docs/leanix/ea/relation-mapping-between-servicenow-and-sap-leanix?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Relations Between Applications and Hardware/Software Items](https://help.sap.com/docs/leanix/ea/relations-between-applications-and-hardware-software-items?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [ServiceNow Integration: Advanced Configuration](https://help.sap.com/docs/leanix/ea/servicenow-advanced-configuration?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [ServiceNow Integration FAQs](https://help.sap.com/docs/leanix/ea/servicenow-integration-faqs?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [Jira Service Management Integration](https://help.sap.com/docs/leanix/ea/jira-service-management-integration?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Configuring the Integration with Jira Service Management](https://help.sap.com/docs/leanix/ea/configuring-integration-with-jira-service-management?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Fact Sheet Mapping Between Jira Service Management and SAP LeanIX](https://help.sap.com/docs/leanix/ea/fact-sheet-mapping-between-jira-service-management-and-sap-leanix?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Relation Mapping Between Jira Service Management and SAP LeanIX](https://help.sap.com/docs/leanix/ea/relation-mapping-between-jira-service-management-and-sap-leanix?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [Apptio Integration](https://help.sap.com/docs/leanix/ea/apptio-integration?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Apptio Technical Overview](https://help.sap.com/docs/leanix/ea/apptio-technical-overview?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Setup in Apptio](https://help.sap.com/docs/leanix/ea/setup-in-apptio?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Configuration of the Apptio Connector](https://help.sap.com/docs/leanix/ea/configuration-of-apptio-connector?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [Collibra Integration](https://help.sap.com/docs/leanix/ea/collibra-integration?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Configuring Collibra Integration](https://help.sap.com/docs/leanix/ea/configuring-collibra-integration?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Conceptual Data Layer Mapping from Collibra to SAP LeanIX](https://help.sap.com/docs/leanix/ea/conceptual-data-layer-mapping-from-collibra-to-sap-leanix?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Fact Sheet Mapping from SAP LeanIX to Collibra](https://help.sap.com/docs/leanix/ea/fact-sheet-mapping-from-sap-leanix-to-collibra?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Relation Mapping from SAP LeanIX to Collibra](https://help.sap.com/docs/leanix/ea/relation-mapping-from-sap-leanix-to-collibra?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Supported Field Types for Conceptual Data Layer Mapping](https://help.sap.com/docs/leanix/ea/supported-field-types-for-conceptual-data-layer-mapping?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Supported Field Types for Fact Sheet Mapping](https://help.sap.com/docs/leanix/ea/supported-field-types-for-fact-sheet-mapping?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [Confluence Integration](https://help.sap.com/docs/leanix/ea/confluence-integration?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [Jira Integration](https://help.sap.com/docs/leanix/ea/jira-integration?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Setting Up the Jira Integration](https://help.sap.com/docs/leanix/ea/setting-up-jira-cloud-projects-integration?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Importing, Exporting, and Linking Fact Sheets and Jira Work Items](https://help.sap.com/docs/leanix/ea/creating-and-linking-fact-sheets-and-jira-issues?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [Jira Marketplace App](https://help.sap.com/docs/leanix/ea/jira-software-integration?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [SAP LeanIX App for Microsoft Teams](https://help.sap.com/docs/leanix/ea/sap-leanix-app-for-microsoft-teams?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [OData Integration](https://help.sap.com/docs/leanix/ea/odata-integration?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Setting Up the OData Integration with Business Intelligence Tools](https://help.sap.com/docs/leanix/ea/setting-up-odata-integration-with-business-intelligence-tools?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [OData Integration Update: Translation Corrections (May 26, 2025)](https://help.sap.com/docs/leanix/ea/odata-integration-update?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [LeanIX Adapter for SAP Integration Suite](https://help.sap.com/docs/leanix/ea/leanix-adapter-for-sap-integration-suite?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [Synchronization Logging](https://help.sap.com/docs/leanix/ea/synchronization-logging?locale=en-US&state=PRODUCTION&version=CLOUD)
  * [Additional Products](https://help.sap.com/docs/leanix/ea/additional-products?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [SAP LeanIX Technology Risk and Compliance](https://help.sap.com/docs/leanix/ea/sap-leanix-technology-risk-and-compliance?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Getting Started: Building Your IT Component Inventory](https://help.sap.com/docs/leanix/ea/getting-started-building-your-it-component-inventory?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Obsolescence Risk Management Capabilities](https://help.sap.com/docs/leanix/ea/obsolescence-risk-management-capabilities?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Technology Obsolescence Risk Statuses and Views in Reports](https://help.sap.com/docs/leanix/ea/technology-obsolescence-risk-statuses-and-views-in-reports?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Obsolescence Risk Management Dashboard](https://help.sap.com/docs/leanix/ea/obsolescence-risk-management-dashboard?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Tutorial: Managing IT Risks Associated with Data Center and Server Locations](https://help.sap.com/docs/leanix/ea/tutorial-managing-it-risks-associated-with-data-center-and-server-locations?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Technology Standards Management Capabilities](https://help.sap.com/docs/leanix/ea/technology-standards-management-capabilities?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [SAP LeanIX Architecture and Road Map Planning](https://help.sap.com/docs/leanix/ea/sap-leanix-architecture-and-road-map-planning?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Getting Started with SAP LeanIX Architecture and Road Map Planning](https://help.sap.com/docs/leanix/ea/getting-started-with-sap-leanix-architecture-and-road-map-planning?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Architecture Decisions](https://help.sap.com/docs/leanix/ea/architecture-decisions?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Architecture Decision Templates](https://help.sap.com/docs/leanix/ea/architecture-decision-templates?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Milestones](https://help.sap.com/docs/leanix/ea/milestones?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Transformations](https://help.sap.com/docs/leanix/ea/transformations?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Transformations Explorer](https://help.sap.com/docs/leanix/ea/transformations-explorer?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Importing and Exporting Transformations via Excel File](https://help.sap.com/docs/leanix/ea/importing-and-exporting-transformations-via-excel-file?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Creating Custom Transformation Templates](https://help.sap.com/docs/leanix/ea/creating-custom-transformation-templates?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Planning Transformations for SAP Solutions](https://help.sap.com/docs/leanix/ea/planning-transformations-for-sap-solutions?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Impacts](https://help.sap.com/docs/leanix/ea/impacts?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Scheduled Changes](https://help.sap.com/docs/leanix/ea/scheduled-changes?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Reports and Roadmaps](https://help.sap.com/docs/leanix/ea/reports-and-roadmaps?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Transition from Transformation Items/Project Fact Sheet to Initiative](https://help.sap.com/docs/leanix/ea/transition-from-transformation-items-project-fact-sheet-to-initiative?locale=en-US&state=PRODUCTION&version=CLOUD)
  * [Developer Guide](https://help.sap.com/docs/leanix/ea/developer-guide?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [Basics](https://help.sap.com/docs/leanix/ea/basics?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Choosing a Technology for Your Integration](https://help.sap.com/docs/leanix/ea/choosing-technology-for-your-integration?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Authentication to SAP LeanIX Services](https://help.sap.com/docs/leanix/ea/authentication-to-sap-leanix-services?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Technical Users](https://help.sap.com/docs/leanix/ea/technical-users?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Configuring Authentication to SAP LeanIX APIs in Postman](https://help.sap.com/docs/leanix/ea/configuring-authentication-to-sap-leanix-apis-in-postman?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Base URL](https://help.sap.com/docs/leanix/ea/base-url?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [Guides and Tutorials](https://help.sap.com/docs/leanix/ea/overview?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Custom Reports](https://help.sap.com/docs/leanix/ea/custom-reports?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Setting Up Your Custom Reports Project](https://help.sap.com/docs/leanix/ea/setting-up-your-custom-reports-project?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Building Your First Custom Report](https://help.sap.com/docs/leanix/ea/building-your-first-custom-report?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Filtering in Custom Reports](https://help.sap.com/docs/leanix/ea/filtering-in-custom-reports?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Using GraphQL Queries with Custom Reports](https://help.sap.com/docs/leanix/ea/using-graphql-queries-with-custom-reports?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Visualizing Data with Custom Reports](https://help.sap.com/docs/leanix/ea/visualizing-data-with-custom-reports?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Creating a Custom Matrix Report](https://help.sap.com/docs/leanix/ea/creating-custom-matrix-report?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Publishing Custom Reports on the SAP LeanIX Store](https://help.sap.com/docs/leanix/ea/publishing-custom-reports-on-sap-leanix-store?locale=en-US&state=PRODUCTION&version=CLOUD)
          * [Review Criteria for Custom Reports](https://help.sap.com/docs/leanix/ea/review-criteria-custom-reports?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Code-Based Automations](https://help.sap.com/docs/leanix/ea/code-based-automations?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Calculating Risk Scores and Updating a Fact Sheet Based on Survey Responses](https://help.sap.com/docs/leanix/ea/calculating-risk-scores-and-updating-fact-sheet-based-on-survey-responses?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Assigning Tags to Fact Sheets Based on Field Value Ranges](https://help.sap.com/docs/leanix/ea/assigning-tags-to-fact-sheets-based-on-custom-calculated-field?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Managing Fact Sheet Tags Dynamically Based on Relation Changes](https://help.sap.com/docs/leanix/ea/managing-fact-sheet-tags-dynamically-based-on-relation-changes?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Categorizing Applications Using the TIME Framework with Tags](https://help.sap.com/docs/leanix/ea/updating-tag-related-to-time-model?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Importing and Exporting Data](https://help.sap.com/docs/leanix/ea/importing-and-exporting-data?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Importing and Updating the Total Annual Costs of Applications](https://help.sap.com/docs/leanix/ea/importing-and-updating-total-annual-costs-of-applications?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Exporting Workspace Snapshots](https://help.sap.com/docs/leanix/ea/exporting-workspace-snapshots?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Bookmarks](https://help.sap.com/docs/leanix/ea/bookmarks?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Retrieving a Diagram by ID](https://help.sap.com/docs/leanix/ea/retrieving-diagram-by-id?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Updating User Permissions](https://help.sap.com/docs/leanix/ea/updating-user-permissions?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Retrieving Survey Results](https://help.sap.com/docs/leanix/ea/retrieving-survey-results?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Sending Alerts to Slack and Microsoft Teams](https://help.sap.com/docs/leanix/ea/sending-alerts-to-slack-and-microsoft-teams?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [SAP LeanIX APIs](https://help.sap.com/docs/leanix/ea/sap-leanix-apis?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [REST APIs](https://help.sap.com/docs/leanix/ea/rest-apis?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [REST APIs Overview](https://help.sap.com/docs/leanix/ea/rest-apis-overview?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [GraphQL API](https://help.sap.com/docs/leanix/ea/graphql-api?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [GraphQL Basics](https://help.sap.com/docs/leanix/ea/graphql-basics?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Filtering in GraphQL](https://help.sap.com/docs/leanix/ea/filtering-in-graphql?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Pagination in GraphQL](https://help.sap.com/docs/leanix/ea/pagination-in-graphql?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Error Handling in GraphQL](https://help.sap.com/docs/leanix/ea/error-handling-in-graphql?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Using GraphQL with Python](https://help.sap.com/docs/leanix/ea/using-graphql-with-python?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Migrating from the Fact Sheets REST API to the GraphQL API](https://help.sap.com/docs/leanix/ea/migrating-from-fact-sheets-rest-api-to-graphql-api?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Sample GraphQL Queries](https://help.sap.com/docs/leanix/ea/sample-queries?locale=en-US&state=PRODUCTION&version=CLOUD)
          * [Retrieving Fact Sheets (GraphQL)](https://help.sap.com/docs/leanix/ea/retrieving-fact-sheets?locale=en-US&state=PRODUCTION&version=CLOUD)
          * [Filtering Fact Sheets (GraphQL)](https://help.sap.com/docs/leanix/ea/filtering-fact-sheets?locale=en-US&state=PRODUCTION&version=CLOUD)
          * [Creating a Fact Sheet (GraphQL)](https://help.sap.com/docs/leanix/ea/creating-fact-sheet?locale=en-US&state=PRODUCTION&version=CLOUD)
          * [Updating a Fact Sheet (GraphQL)](https://help.sap.com/docs/leanix/ea/updating-fact-sheet?locale=en-US&state=PRODUCTION&version=CLOUD)
          * [Managing Fact Sheet Relations (GraphQL)](https://help.sap.com/docs/leanix/ea/managing-relations-between-fact-sheets?locale=en-US&state=PRODUCTION&version=CLOUD)
          * [Managing Fact Sheet Tags (GraphQL)](https://help.sap.com/docs/leanix/ea/managing-tags-on-fact-sheet?locale=en-US&state=PRODUCTION&version=CLOUD)
          * [Managing Fact Sheet Resources (GraphQL)](https://help.sap.com/docs/leanix/ea/managing-resources-on-fact-sheet?locale=en-US&state=PRODUCTION&version=CLOUD)
          * [Managing Fact Sheet Subscriptions (GraphQL)](https://help.sap.com/docs/leanix/ea/managing-fact-sheet-subscriptions?locale=en-US&state=PRODUCTION&version=CLOUD)
          * [Retrieving Event Logs for a Fact Sheet (GraphQL)](https://help.sap.com/docs/leanix/ea/retrieving-event-logs-for-fact-sheet?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Integration API](https://help.sap.com/docs/leanix/ea/integration-api?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Getting Started with the Integration API](https://help.sap.com/docs/leanix/ea/getting-started-with-integration-api?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Inbound Processors](https://help.sap.com/docs/leanix/ea/inbound-processors?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Outbound Processors](https://help.sap.com/docs/leanix/ea/outbound-processors?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Advanced Use Cases for the Integration API](https://help.sap.com/docs/leanix/ea/advanced-use-cases-for-integration-api?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Integration REST API](https://help.sap.com/docs/leanix/ea/integration-rest-api?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Initiating Integration API Runs with Python](https://help.sap.com/docs/leanix/ea/initiating-integration-api-runs-with-python?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Configuring Automated Nightly Runs for Inbound Processors](https://help.sap.com/docs/leanix/ea/configuring-automated-nightly-runs-for-inbound-processors?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Best Practices for the Integration API](https://help.sap.com/docs/leanix/ea/best-practices-for-integration-api?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Integration API Tutorials](https://help.sap.com/docs/leanix/ea/integration-api-tutorials?locale=en-US&state=PRODUCTION&version=CLOUD)
          * [Importing and Updating Fact Sheets](https://help.sap.com/docs/leanix/ea/importing-and-updating-fact-sheets?locale=en-US&state=PRODUCTION&version=CLOUD)
          * [Calculating Scores from Numeric Fields and Updating Custom Fact Sheet Fields](https://help.sap.com/docs/leanix/ea/calculating-scores-from-numeric-fields-and-updating-custom-fact-sheet-fields?locale=en-US&state=PRODUCTION&version=CLOUD)
          * [Importing Resources to Fact Sheets](https://help.sap.com/docs/leanix/ea/importing-resources-to-fact-sheets?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Webhooks](https://help.sap.com/docs/leanix/ea/webhooks?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [PUSH Webhooks](https://help.sap.com/docs/leanix/ea/push-webhooks?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [PULL Webhooks](https://help.sap.com/docs/leanix/ea/pull-webhooks?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Webhook Events](https://help.sap.com/docs/leanix/ea/webhook-events?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Webhook Payloads](https://help.sap.com/docs/leanix/ea/webhook-payloads?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Rate Limiting](https://help.sap.com/docs/leanix/ea/rate-limiting?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Response Status Codes](https://help.sap.com/docs/leanix/ea/response-status-codes?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [API Updates](https://help.sap.com/docs/leanix/ea/api-updates?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Poll API Deprecation: Transition to the New Survey API](https://help.sap.com/docs/leanix/ea/poll-api-updates-transition-to-new-survey-api?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [GraphQL API: Error Handling for Multiple Mutations Sent in a Single Request (July 28, 2025)](https://help.sap.com/docs/leanix/ea/api-updates-graphql-error-handling?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Self-Built Software Discovery API: Asynchronous Processing of SBOM File Ingestions (April 7, 2025)](https://help.sap.com/docs/leanix/ea/api-updates-sbom-async-processing?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [GraphQL API Changes (January 15, 2025)](https://help.sap.com/docs/leanix/ea/api-updates-graphql-api-changes?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [Reporting Framework and CLI](https://help.sap.com/docs/leanix/ea/reporting-framework-and-cli?locale=en-US&state=PRODUCTION&version=CLOUD)
  * [Additional Resources](https://help.sap.com/docs/leanix/ea/additional-resources?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [Data Privacy Statement: SAP LeanIX Workspace](https://help.sap.com/docs/leanix/ea/data-privacy-statement-sap-leanix-workspace?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [Cookies and Local Storage Policy: SAP LeanIX Workspace](https://help.sap.com/docs/leanix/ea/cookies-and-local-storage-policy-sap-leanix-workspace?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [SAP LeanIX Applications Terms and Conditions (Microsoft Teams)](https://help.sap.com/docs/leanix/ea/sap-leanix-applications-terms-and-conditions-microsoft-teams?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [Geo-Blocking](https://help.sap.com/docs/leanix/ea/geo-blocking?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [Data Quality Control Mechanisms](https://help.sap.com/docs/leanix/ea/data-quality-control-mechanisms?locale=en-US&state=PRODUCTION&version=CLOUD)
